@@ -1,35 +1,16 @@
 import ctypes
 import sys
 from .pointer import Pointer
-from ._cstd import c_malloc, c_free, c_realloc, c_calloc
+from ._cstd import c_malloc, c_free, c_realloc
 from typing import TypeVar, Generic, NoReturn, Optional
+from .exceptions import IsMallocPointerError, AllocationError
 
-__all__ = (
-    "IsMallocPointerError",
-    "MallocPointer",
-    "malloc",
-    "free",
-    "realloc",
-    "AllocationError",
-    "calloc"
-)
+__all__ = ("MallocPointer", "malloc", "free", "realloc")
 
 
 T = TypeVar("T")
 
 
-class IsMallocPointerError(Exception):
-    """Raised when trying perform an operation on a malloc pointer that isn't supported."""  # noqa
-
-    pass
-
-
-class AllocationError(Exception):
-    """Raised when a memory allocation fails."""
-
-    pass
-
-
 class MallocPointer(Pointer, Generic[T]):
     """Class representing a pointer created by malloc."""
 
@@ -81,7 +62,10 @@ class MallocPointer(Pointer, Generic[T]):
         raise IsMallocPointerError("cannot assign to malloc pointer")
 
     def __repr__(self) -> str:
-        return f"<pointer to allocated memory at {hex(self.address)}>"
+        return f"<pointer to {self.size} bytes of memory at {hex(self.address)}>"  # noqa
+
+    def __rich__(self) -> str:
+        return f"<pointer to [green]{self.size} bytes[/green] of memory at [cyan]{hex(self.address)}[/cyan]>"  # noqa
 
     def move(self, data: Pointer[T]) -> None:
         """Move data to the allocated memory."""
@@ -112,13 +96,19 @@ class MallocPointer(Pointer, Generic[T]):
     def dereference(self):
         """Dereference the pointer."""
         if self.freed:
-            raise MemoryError("memory has been freed")
+            raise MemoryError("cannot dereference memory that has been freed")
 
         if not self.assigned:
-            raise MemoryError("pointer has no value")
+            raise MemoryError("cannot dereference pointer that has no value")
 
         return super().dereference()
 
+    def __add__(self, amount: int):
+        return MallocPointer(self.address + amount, self.size, self.assigned)
+
+    def __sub__(self, amount: int):
+        return MallocPointer(self.address - amount, self.size, self.assigned)
+
 
 def malloc(size: int) -> MallocPointer:
     """Allocate memory for a given size."""
@@ -146,8 +136,3 @@ def realloc(target: MallocPointer, size: int) -> None:
         raise AllocationError("failed to resize memory")
 
     target.size = size
-
-
-def calloc(num: int, size: int) -> MallocPointer:
-    """Allocate a number of blocks with a given size."""
-    return MallocPointer(c_calloc(num, size), size)
